Changes for bmi-geotiff
=======================

0.2 (2021-04-22)
----------------

- Add user and API documentation, deplot to Read the Docs (#3)
- Set up CI tasks using GitHub Actions (#4)


0.1 (2021-04-16)
----------------

- Create base library that uses xarray
- Write tests for library
- Implement BMI for GeoTiff class from template generated by `bmipy-render`
- Make demo Jupyter Notebooks
